function plot_figure_arcs(centers,rs,active_arcs,...
    disk_sequence,arcs_sizes,centers0,rs0,xyw,xywc)

%--------------------------------------------------------------------------
% Object.
% Plot of disks, nodes and boundary.
%--------------------------------------------------------------------------

% Troubleshooting.

if nargin < 3, active_arcs=[]; disk_sequence=[]; arcs_sizes=[]; end
if nargin < 6, centers0=[]; rs0=[]; end
if nargin < 8, xyw=[]; end
if nargin < 9, xywc=[]; end

% Special settings
add_text=0;     % 0: no text added; 1: text added.
text_color='m'; % color of the text.

gray_dark=[150,150,150]/256; 
gray_mid=[220,220,220]/256;

plot_start=0; % 0: no plot, 1: Plot starting point of the curve in red.
disk_color=gray_mid;    % color of the disk
circle_color=gray_dark; % color of the circle
circles_size=0.35;

%--------------------------------------------------------------------------
% 1. Plot disks. 
%--------------------------------------------------------------------------

for k=1:length(rs)
    center=centers(k,:);
    r=rs(k);
    theta=linspace(0,2*pi,1000);
    rr=linspace(0,r,200);
    [TH,R]=meshgrid(theta,rr);
    TH=TH(:); R=R(:);
    X=center(1)+R.*cos(TH); Y=center(2)+R.*sin(TH);
    plot(X,Y,'o','MarkerEdgeColor',disk_color,...
                       'MarkerFaceColor',disk_color,...
                       'MarkerSize',2)
    hold on;
end



%--------------------------------------------------------------------------
% 2. Plot boundary of each disk.
%--------------------------------------------------------------------------
for k=1:length(rs)
    center=centers(k,:);
    r=rs(k);
    theta=linspace(0,2*pi,1000);
    TH=TH(:); R=R(:);
    X=center(1)+r*cos(TH); Y=center(2)+r*sin(TH);
    plot(X,Y,'-','MarkerEdgeColor',circle_color,...
                       'MarkerFaceColor',circle_color,...
                       'MarkerSize',circles_size)
    hold on;
end


axis off;
axis equal;

M=size(rs,1);

%--------------------------------------------------------------------------
% Plotting sequences of arcs of the boundary.
%--------------------------------------------------------------------------
T=active_arcs;

for ii=1:length(arcs_sizes)

    init_ii=sum(arcs_sizes(1:ii-1))+1;
    end_ii=sum(arcs_sizes(1:ii));

    for jj=init_ii:end_ii
        th=linspace(0,2*pi,100);
        center=centers(disk_sequence(jj),:);
        r=rs(disk_sequence(jj));
        angs=T(jj,:);
        angsv=angs(1):(angs(2)-angs(1))/100:angs(2);
        angsv=angsv';
        pts=[center(1)+r*cos(angsv) center(2)+r*sin(angsv)];
         plot(pts(:,1),pts(:,2),'k-','LineWidth',4,...
            'MarkerEdgeColor','w',...
            'MarkerFaceColor','g',...
            'MarkerSize',1);

        if plot_start & ii == 1 & jj == init_ii
                    plot(pts(1,1),pts(1,2),'k.','LineWidth',4,...
            'MarkerEdgeColor','r',...
            'MarkerFaceColor','r',...
            'MarkerSize',40);
        end

        if add_text
            pos=max([1 floor(size(pts,1)/2)]);
            strL=strcat('\Gamma_{',num2str(ii),',',num2str(jj),'}');
            text(pts(pos,1)*1.05,pts(pos,2)*1.05,strL,'FontSize', 18,...
                'Color',text_color);
        end

    end
end



%--------------------------------------------------------------------------
% PLOT POINTSET 1
%--------------------------------------------------------------------------
if isempty(xyw) == 0
    plot(xyw(:,1),xyw(:,2),'bo',...
        'MarkerEdgeColor','b','MarkerFaceColor','b',...
        'MarkerSize',1);
end

%--------------------------------------------------------------------------
% PLOT POINTSET 2
%--------------------------------------------------------------------------
if isempty(xywc) == 0
    plot(xywc(:,1),xywc(:,2),'ro',...
        'MarkerEdgeColor','r','MarkerFaceColor','r',...
        'MarkerSize',4);
end

hold off




